# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from .x_session_manager_client import XSessionManagerClient as XSessionManagerClient_379b0f69

class SessionManager(XSessionManagerClient_379b0f69):
    """
    Service Class

    The SessionManager service provides an interface to the session manager of the desktop.
    
    A session manager keeps track of applications that are running when the desktop shuts down and starts them again in the same state they were left when the desktop starts up the next time. To be able to do this the session manager needs cooperation from applications; applications have to provide sufficient information to be started again as well as restore the state they were left in. The normal flow of operation looks like this:

    See Also:
        `API SessionManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1SessionManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.SessionManager'
    __ooo_type_name__: str = 'service'


__all__ = ['SessionManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XEnhancedCustomShapeDefaulter(XInterface_8f010a43):
    """

    See Also:
        `API XEnhancedCustomShapeDefaulter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XEnhancedCustomShapeDefaulter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XEnhancedCustomShapeDefaulter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XEnhancedCustomShapeDefaulter'

    @abstractmethod
    def createCustomShapeDefaults(self, aShapeType: str) -> None:
        """
        This interface allows to create shape properties for the given \"ShapeType\".
        
        The \"ShapeType\" string can be empty then the current \"ShapeType\" of the shape is used.
        
        SJ: following shape types can't be created with this method, they are part of the gallery (soon they also will be added) gallery: quadrat gallery: round-quadrat gallery: circle gallery: circle-pie gallery: frame gallery: flower gallery: cloud gallery: puzzle gallery: octagon-bevel gallery: diamond-bevel gallery: up-right-arrow gallery: up-right-down-arrow gallery: corner-right-arrow gallery: split-arrow gallery: up-right-arrow-callout gallery: split-round-arrow gallery: s-sharped-arrow Gallery: star6 Gallery: star12 Gallery: concave-star6 Gallery: signet Gallery: doorplate gallery: fontwork-arch-left-curve gallery: fontwork-arch-right-curve gallery: fontwork-arch-left-pour gallery: fontwork-arch-right-pour
        """
        ...

__all__ = ['XEnhancedCustomShapeDefaulter']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form.runtime
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing


class FilterEvent(EventObject_a3d70b03):
    """
    Struct Class

    is an event fired by a filter controller, when the filter managed by the controller changes.
    
    **since**
    
        OOo 3.3

    See Also:
        `API FilterEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1form_1_1runtime_1_1FilterEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.FilterEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.form.runtime.FilterEvent'
    """Literal Constant ``com.sun.star.form.runtime.FilterEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, DisjunctiveTerm: typing.Optional[int] = 0, FilterComponent: typing.Optional[int] = 0, PredicateExpression: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            DisjunctiveTerm (int, optional): DisjunctiveTerm value.
            FilterComponent (int, optional): FilterComponent value.
            PredicateExpression (str, optional): PredicateExpression value.
        """

        if isinstance(Source, FilterEvent):
            oth: FilterEvent = Source
            self.Source = oth.Source
            self.DisjunctiveTerm = oth.DisjunctiveTerm
            self.FilterComponent = oth.FilterComponent
            self.PredicateExpression = oth.PredicateExpression
            return

        kargs = {
            "Source": Source,
            "DisjunctiveTerm": DisjunctiveTerm,
            "FilterComponent": FilterComponent,
            "PredicateExpression": PredicateExpression,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._disjunctive_term = kwargs["DisjunctiveTerm"]
        self._filter_component = kwargs["FilterComponent"]
        self._predicate_expression = kwargs["PredicateExpression"]
        inst_keys = ('DisjunctiveTerm', 'FilterComponent', 'PredicateExpression')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def DisjunctiveTerm(self) -> int:
        """
        denotes the index of the disjunctive term to which the event applies, if any.
        """
        return self._disjunctive_term

    @DisjunctiveTerm.setter
    def DisjunctiveTerm(self, value: int) -> None:
        self._disjunctive_term = value

    @property
    def FilterComponent(self) -> int:
        """
        denotes the index of the filter component to which the event applies, if any.
        """
        return self._filter_component

    @FilterComponent.setter
    def FilterComponent(self, value: int) -> None:
        self._filter_component = value

    @property
    def PredicateExpression(self) -> str:
        """
        denotes the predicate expression associated with the event.
        """
        return self._predicate_expression

    @PredicateExpression.setter
    def PredicateExpression(self, value: str) -> None:
        self._predicate_expression = value


__all__ = ['FilterEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.logging
from __future__ import annotations
from abc import abstractmethod
from .x_log_formatter import XLogFormatter as XLogFormatter_e23d0d1d

class PlainTextFormatter(XLogFormatter_e23d0d1d):
    """
    Service Class

    specifies a service which formats log records as single line plain text
    
    Every log record, as passed to XLogFormatter.format(), will be formatted into a single text line, assembling the sequence number, the thread ID, the time of the logged event, the source class/method name (if applicable), and the log message.
    
    **since**
    
        OOo 2.3

    See Also:
        `API PlainTextFormatter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1logging_1_1PlainTextFormatter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.logging'
    __ooo_full_ns__: str = 'com.sun.star.logging.PlainTextFormatter'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self) -> None:
        """
        creates a PlainTextFormatter instance
        """
        ...

__all__ = ['PlainTextFormatter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from abc import abstractmethod
from .x_layer import XLayer as XLayer_4cd50fcb

class XUpdatableLayer(XLayer_4cd50fcb):
    """
    Provides access to a read-write layer of configuration data for a given component and entity.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XUpdatableLayer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdatableLayer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XUpdatableLayer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XUpdatableLayer'

    @abstractmethod
    def replaceWith(self, aNewLayer: XLayer_4cd50fcb) -> None:
        """
        Replaces the current layer with the layer given as input parameter.
        
        After the replacement has been performed, reading the layer will return the new content. Some implementations may not support this, so after an update XLayer.readData() may fail.

        Raises:
            com.sun.star.lang.NullPointerException: ``NullPointerException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
            MalformedDataException: ``MalformedDataException``
        """
        ...

__all__ = ['XUpdatableLayer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class ConversionDirection(Enum):
    """
    Enum Class


    See Also:
        `API ConversionDirection <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2.html#a884af1a9fc4a39bcfd381c3acaa30997>`_
    """
    __ooo_ns__: str = "com.sun.star.linguistic2"
    __ooo_full_ns__: str = "com.sun.star.linguistic2.ConversionDirection"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.linguistic2.ConversionDirection"

    FROM_LEFT = "FROM_LEFT"
    """
    the text to be looked for should match the left part of a dictionary entry.
    """
    FROM_RIGHT = "FROM_RIGHT"
    """
    the text to be looked for should match the right part of a dictionary entry.
    """

__all__ = ["ConversionDirection"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.graphic
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..geometry.real_rectangle3_d import RealRectangle3D as RealRectangle3D_d9d0e04

class XPrimitive3D(XInterface_8f010a43):
    """
    XPrimitive3D interface.
    
    This is the basic interface for graphic 3D primitives. They need to be able

    See Also:
        `API XPrimitive3D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1graphic_1_1XPrimitive3D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.graphic'
    __ooo_full_ns__: str = 'com.sun.star.graphic.XPrimitive3D'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.graphic.XPrimitive3D'

    @abstractmethod
    def getDecomposition(self, aViewParameters: typing.Tuple[PropertyValue_c9610c73, ...]) -> typing.Tuple[XPrimitive3D, ...]:
        """
        Retrieve decomposed list of simpler primitives.
        
        double Time
        
        Defines the point in time for which the geometry is defined. This may lead to varied results for animated objects. This value is defined in the range [0.0 .. n[, negative values are not allowed. If not given, a value of 0.0 is implied.
        """
        ...
    @abstractmethod
    def getRange(self, aViewParameters: typing.Tuple[PropertyValue_c9610c73, ...]) -> RealRectangle3D_d9d0e04:
        """
        Retrieve bound rect of primitive.
        
        This method calculates the actual bound rect of the area in world coordinates. Note that for view-dependent primitives, the necessary pixel adjustments are taken into account. For that reason the ViewParameters need to be given.
        """
        ...

__all__ = ['XPrimitive3D']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.animations
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class TimeFilterPair(object):
    """
    Struct Class


    See Also:
        `API TimeFilterPair <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1animations_1_1TimeFilterPair.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.TimeFilterPair'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.animations.TimeFilterPair'
    """Literal Constant ``com.sun.star.animations.TimeFilterPair``"""

    def __init__(self, Time: typing.Optional[float] = 0.0, Progress: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Time (float, optional): Time value.
            Progress (float, optional): Progress value.
        """
        super().__init__()

        if isinstance(Time, TimeFilterPair):
            oth: TimeFilterPair = Time
            self.Time = oth.Time
            self.Progress = oth.Progress
            return

        kargs = {
            "Time": Time,
            "Progress": Progress,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._time = kwargs["Time"]
        self._progress = kwargs["Progress"]


    @property
    def Time(self) -> float:
        return self._time

    @Time.setter
    def Time(self, value: float) -> None:
        self._time = value

    @property
    def Progress(self) -> float:
        return self._progress

    @Progress.setter
    def Progress(self, value: float) -> None:
        self._progress = value


__all__ = ['TimeFilterPair']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.report.calculation import Calculation as Calculation
from ...lo.report.fixed_line import FixedLine as FixedLine
from ...lo.report.fixed_text import FixedText as FixedText
from ...lo.report.force_new_page import ForceNewPage as ForceNewPage
from ...lo.report.format_condition import FormatCondition as FormatCondition
from ...lo.report.formatted_field import FormattedField as FormattedField
from ...lo.report.function import Function as Function
from ...lo.report.group import Group as Group
from ...lo.report.group_keep_together import GroupKeepTogether as GroupKeepTogether
from ...lo.report.group_on import GroupOn as GroupOn
from ...lo.report.groups import Groups as Groups
from ...lo.report.image_control import ImageControl as ImageControl
from ...lo.report.keep_together import KeepTogether as KeepTogether
from ...lo.report.report_control_format import ReportControlFormat as ReportControlFormat
from ...lo.report.report_control_model import ReportControlModel as ReportControlModel
from ...lo.report.report_definition import ReportDefinition as ReportDefinition
from ...lo.report.report_engine import ReportEngine as ReportEngine
from ...lo.report.report_print_option import ReportPrintOption as ReportPrintOption
from ...lo.report.section import Section as Section
from ...lo.report.section_page_break import SectionPageBreak as SectionPageBreak
from ...lo.report.shape import Shape as Shape
from ...lo.report.x_fixed_line import XFixedLine as XFixedLine
from ...lo.report.x_fixed_text import XFixedText as XFixedText
from ...lo.report.x_format_condition import XFormatCondition as XFormatCondition
from ...lo.report.x_formatted_field import XFormattedField as XFormattedField
from ...lo.report.x_function import XFunction as XFunction
from ...lo.report.x_functions import XFunctions as XFunctions
from ...lo.report.x_functions_supplier import XFunctionsSupplier as XFunctionsSupplier
from ...lo.report.x_group import XGroup as XGroup
from ...lo.report.x_groups import XGroups as XGroups
from ...lo.report.x_image_control import XImageControl as XImageControl
from ...lo.report.x_report_component import XReportComponent as XReportComponent
from ...lo.report.x_report_control_format import XReportControlFormat as XReportControlFormat
from ...lo.report.x_report_control_model import XReportControlModel as XReportControlModel
from ...lo.report.x_report_definition import XReportDefinition as XReportDefinition
from ...lo.report.x_report_engine import XReportEngine as XReportEngine
from ...lo.report.x_section import XSection as XSection
from ...lo.report.x_shape import XShape as XShape



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd

class XComplexDescriptionAccess(XChartDataArray_df4c0cdd):
    """
    Offers access to complex column and row descriptions.
    
    Can be obtained from interface XChartDocument via method getData().
    
    **since**
    
        OOo 3.3

    See Also:
        `API XComplexDescriptionAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1XComplexDescriptionAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.XComplexDescriptionAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.XComplexDescriptionAccess'

    @abstractmethod
    def getComplexColumnDescriptions(self) -> typing.Tuple[typing.Tuple[str, ...], ...]:
        """
        retrieves the description texts for all columns.
        """
        ...
    @abstractmethod
    def getComplexRowDescriptions(self) -> typing.Tuple[typing.Tuple[str, ...], ...]:
        """
        retrieves the description texts for all rows.
        """
        ...
    @abstractmethod
    def setComplexColumnDescriptions(self, rColumnDescriptions: typing.Tuple[typing.Tuple[str, ...], ...]) -> None:
        """
        sets the description texts for all columns.
        """
        ...
    @abstractmethod
    def setComplexRowDescriptions(self, rRowDescriptions: typing.Tuple[typing.Tuple[str, ...], ...]) -> None:
        """
        sets the description texts for all rows.
        """
        ...

__all__ = ['XComplexDescriptionAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.x_bitmap import XBitmap as XBitmap_70cd0909

class NumberingLevel(ABC):
    """
    Service Class

    These properties describe the numbering of a paragraph.
    
    NumberType determines the type of the numbering symbol. Depending on this setting, some of the following values will be ignored.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API NumberingLevel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1NumberingLevel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.NumberingLevel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BulletFontName(self) -> str:
        """
        This is the name of the font that is used for the bullet.
        """
        ...

    @abstractproperty
    def BulletId(self) -> int:
        """
        The bullet symbol with this code in the assigned font is used.
        """
        ...

    @abstractproperty
    def CharStyleName(self) -> str:
        """
        This is the name of the character style that is used for the symbol(s).
        """
        ...

    @abstractproperty
    def GraphicBitmap(self) -> XBitmap_70cd0909:
        """
        This is the graphic bitmap to use as a symbol.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def GraphicURL(self) -> str:
        """
        This is the URL of a graphic file to use as a symbol.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the GraphicBitmap property.
        """
        ...

    @abstractproperty
    def ListFormat(self) -> str:
        """
        Format string used to generate actual numbering.
        
        It contains placeholders (like %1%, %2%, etc) where corresponding level numberings are inserted.
        
        This is more flexible way to provide multilevel numbering with complex format string. This property is a replacement for Prefix and Suffix: if ListFormat is provided, they are not used anymore.
        
        Example: ListFormat \"(%1% %2%.%3%)\" can be resolved to numbering in actual multilevel list like \"(4 1.3)\".
        
        **since**
        
            LibreOffice 7.2
        """
        ...

    @abstractproperty
    def NumberingType(self) -> int:
        """
        specifies the type of numbering.
        """
        ...

    @abstractproperty
    def ParentNumbering(self) -> int:
        """
        specifies the number of higher numbering levels that are included in the representation of the current number.
        """
        ...

    @abstractproperty
    def Prefix(self) -> str:
        """
        This prefix is inserted in front of the numbering symbol(s).
        """
        ...

    @abstractproperty
    def StartWith(self) -> int:
        """
        This specifies the start value for the numbering.
        """
        ...

    @abstractproperty
    def Suffix(self) -> str:
        """
        This suffix is inserted after the numbering symbol(s).
        """
        ...


__all__ = ['NumberingLevel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class InterpolationMode(object):
    """
    Const Class

    These constants specify the interpolation type for animation frames.
    
    With this constants, one specifies the way of interpolation that takes place between two consecutive frames of a discrete animation sequence.
    
    **since**
    
        OOo 2.0

    See Also:
        `API InterpolationMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1InterpolationMode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.InterpolationMode'
    __ooo_type_name__: str = 'const'

    NEAREST_NEIGHBOR = 1
    """
    Perform a nearest neighbor interpolation.
    
    That is, when interpolating between two values v0 and v1, positioned at t0 and t1, take the one which has the closest t coordinate.
    """
    LINEAR = 2
    """
    Perform a linear interpolation.
    
    That is, when interpolating at position t between two values v0 and v1, positioned at t0 and t1, take the sum of v0 weighted with (t-t0) and v1 weighted with (t1-t).
    """
    CUBIC = 3
    """
    Perform a cubic interpolation.
    
    That is, when interpolating at position t, take the four closest data points v0, v1, v2, and v3, fit a cubic curve through them, and take the interpolated value from this cubic curve.
    """
    BEZIERSPLINE3 = 4
    """
    Perform a cubic Bezier spline interpolation.
    
    That is, when interpolating at position t, take the three closest data points v0, v1, and v2, fit a cubic Bezier spline through them, and take the interpolated value from this cubic curve.
    """
    BEZIERSPLINE4 = 5
    """
    Perform a quadric Bezier spline interpolation.
    
    That is, when interpolating at position t, take the four closest data points v0, v1, v2, and v3, fit a quadric Bezier spline through them, and take the interpolated value from this quadric curve.
    """

__all__ = ['InterpolationMode']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..frame.x_frame import XFrame as XFrame_7a570956
    from ..frame.x_model import XModel as XModel_7a6e095c
    from .x_report_definition import XReportDefinition as XReportDefinition_ec30e81
    from ..sdbc.x_connection import XConnection as XConnection_a36a0b0c
    from ..task.x_status_indicator import XStatusIndicator as XStatusIndicator_e2d00d34
    from ..util.url import URL as URL_57ad07b9

class XReportEngine(XPropertySet_bc180bfa, XComponent_98dc0ab5):
    """
    identifies a XReportEngine which allows the creation of OpenDocument files.
    
    The following events are supported by the report engine. OnPageStarted Is fired when a new page started. OnReportStarted Is fired when a new report started. OnGroupStarted Is fired when a new group started. OnGroupEnded Is fired when the group ended. OnReportEnded Is fired when the report ended. OnPageEnded Is fired when the page ended.

    See Also:
        `API XReportEngine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportEngine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XReportEngine'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XReportEngine'

    @abstractmethod
    def createDocument(self) -> URL_57ad07b9:
        """
        creates a report document.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def createDocumentAlive(self, frame: XFrame_7a570956) -> XModel_7a6e095c:
        """
        creates a report document.
        
        OJ: Has to be discussed if this method is useful.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def createDocumentModel(self) -> XModel_7a6e095c:
        """
        creates a report document.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def interrupt(self) -> None:
        """
        allows to interrupt the creation process of the report document.

        Raises:
            com.sun.star.lang.DisposedException: ``DisposedException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractproperty
    def ActiveConnection(self) -> XConnection_a36a0b0c:
        """
        specifies the active connection which is used to create the resulting report.
        """
        ...

    @abstractproperty
    def MaxRows(self) -> int:
        """
        defines the maximum number of rows which should be fetched for the report.
        
        If the limit is exceeded, the excess rows are silently dropped. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def ReportDefinition(self) -> XReportDefinition_ec30e81:
        """
        specifies the report definition object which is used to create the resulting report.
        """
        ...

    @abstractproperty
    def StatusIndicator(self) -> XStatusIndicator_e2d00d34:
        """
        specifies the status indicator which shows the progress of the report generation process.
        """
        ...


__all__ = ['XReportEngine']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.security
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_certificate_extension import XCertificateExtension as XCertificateExtension_6ead10f8
if typing.TYPE_CHECKING:
    from .cert_alt_name_entry import CertAltNameEntry as CertAltNameEntry_1ce50ec2

class XSanExtension(XCertificateExtension_6ead10f8):
    """
    Interface of a X509 Subject Alternative Name Certificate Extension.
    
    This interface represents a x509 certificate extension.

    See Also:
        `API XSanExtension <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1security_1_1XSanExtension.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.XSanExtension'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.security.XSanExtension'

    @abstractproperty
    def AlternativeNames(self) -> typing.Tuple[CertAltNameEntry_1ce50ec2, ...]:
        """
        Contains the alternative names of a certificate.
        """
        ...


__all__ = ['XSanExtension']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.script.vba.vba_event_id import VBAEventId as VBAEventId
with suppress(ImportError):
    from ....dyn.script.vba.vba_event_id import VBAEventIdEnum as VBAEventIdEnum
with suppress(ImportError):
    from ....dyn.script.vba.vba_event_processor import VBAEventProcessor as VBAEventProcessor
with suppress(ImportError):
    from ....dyn.script.vba.vba_macro_resolver import VBAMacroResolver as VBAMacroResolver
with suppress(ImportError):
    from ....dyn.script.vba.vba_script_event import VBAScriptEvent as VBAScriptEvent
with suppress(ImportError):
    from ....dyn.script.vba.vba_script_event_id import VBAScriptEventId as VBAScriptEventId
with suppress(ImportError):
    from ....dyn.script.vba.vba_script_event_id import VBAScriptEventIdEnum as VBAScriptEventIdEnum
with suppress(ImportError):
    from ....dyn.script.vba.vba_spreadsheet_event_processor import VBASpreadsheetEventProcessor as VBASpreadsheetEventProcessor
with suppress(ImportError):
    from ....dyn.script.vba.vba_text_event_processor import VBATextEventProcessor as VBATextEventProcessor
with suppress(ImportError):
    from ....dyn.script.vba.xvba_compatibility import XVBACompatibility as XVBACompatibility
with suppress(ImportError):
    from ....dyn.script.vba.xvba_event_processor import XVBAEventProcessor as XVBAEventProcessor
with suppress(ImportError):
    from ....dyn.script.vba.xvba_macro_resolver import XVBAMacroResolver as XVBAMacroResolver
with suppress(ImportError):
    from ....dyn.script.vba.xvba_module_info import XVBAModuleInfo as XVBAModuleInfo
with suppress(ImportError):
    from ....dyn.script.vba.xvba_script_listener import XVBAScriptListener as XVBAScriptListener



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..util.revision_tag import RevisionTag as RevisionTag_a6770b31

class XDocumentRevisionListPersistence(XInterface_8f010a43):
    """
    interface to load or store a list of document revisions from or to a document using the packed XML file format

    See Also:
        `API XDocumentRevisionListPersistence <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentRevisionListPersistence.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XDocumentRevisionListPersistence'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XDocumentRevisionListPersistence'

    @abstractmethod
    def load(self, Storage: XStorage_8e460a32) -> typing.Tuple[RevisionTag_a6770b31, ...]:
        """
        Loads a list of available revisions from a storage.
        
        This method does not load any revision itself

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def store(self, Storage: XStorage_8e460a32, List: typing.Tuple[RevisionTag_a6770b31, ...]) -> None:
        """
        Stores a list of available revisions to a storage.
        
        This method does not store revisions themselves

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...

__all__ = ['XDocumentRevisionListPersistence']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class TransliterationModulesExtra(object):
    """
    Const Class

    Extra transliteration module enumeration to use with XTransliteration.loadModule()
    
    The values used in this group need to be different from the ones in TransliterationModules and TransliterationModulesNew!

    See Also:
        `API TransliterationModulesExtra <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1TransliterationModulesExtra.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModulesExtra'
    __ooo_type_name__: str = 'const'

    SENTENCE_CASE = 200
    """
    The first character of the sentence is put in upper case.
    """
    TITLE_CASE = 201
    """
    The first character of the word is put in upper case.
    
    This one is part
    """
    TOGGLE_CASE = 202
    """
    All characters of the word are to change their case from small letters to capital letters and vice versa.
    """
    IGNORE_DIACRITICS_CTL = 1073741824
    """
    Ignore diacritics.
    
    Despite the _CTL name suffix this is not only about CTL/Arabic diacritic characters, though these are handled as well, but the transliteration decomposes and removes any diacritic from characters.
    
    Because we cannot extend the TransliterationModules enum we use TransliterationModulesExtra and it will act the same way.
    """
    IGNORE_KASHIDA_CTL = 2048
    """
    Ignore Kashida mark.
    """
    END_OF_MODULE = 0

__all__ = ['TransliterationModulesExtra']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..geometry.matrix2_d import Matrix2D as Matrix2D_b26c0b5f
    from ..geometry.real_bezier_segment2_d import RealBezierSegment2D as RealBezierSegment2D_4a970fa2
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..geometry.x_mapping2_d import XMapping2D as XMapping2D_ca1e0c0e
    from .font_info import FontInfo as FontInfo_bded0be9
    from .font_request import FontRequest as FontRequest_e4890d46
    from .render_state import RenderState as RenderState_e4490d27
    from .string_context import StringContext as StringContext_d50e22
    from .stroke_attributes import StrokeAttributes as StrokeAttributes_2dd10f65
    from .texture import Texture as Texture_b2e70bb7
    from .view_state import ViewState as ViewState_cab30c62
    from .x_bitmap import XBitmap as XBitmap_b1b70b7b
    from .x_cached_primitive import XCachedPrimitive as XCachedPrimitive_29890f0f
    from .x_canvas_font import XCanvasFont as XCanvasFont_e3380d11
    from .x_graphic_device import XGraphicDevice as XGraphicDevice_ca80e2c
    from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20
    from .x_text_layout import XTextLayout as XTextLayout_e44a0d41

class XCanvas(XInterface_8f010a43):
    """
    Central interface for rendering.
    
    This is the central interface for graphical output production, and the place where all draw methods are located.
    
    Some notes are in order to explain the concepts used here. The XCanvas interface is free of client-modifiable state, i.e. it can be used safely and without external synchronization in a multi-threaded environment. On the other hand, this implies that for nearly every canvas operation, external state is required. This is provided by ViewState and RenderState in a unified fashion, supplemented by a few extra state parameters for some methods (e.g. textured polygons or text rendering).
    
    When used careless, this scheme can be inefficient to some extend, because internally, view, render and other states have to be combined before rendering. This is especially expensive for complex clip polygons, i.e. when both ViewState and RenderState have a complex clip polygon set, which have to be intersected before rendering. It is therefore recommended to combine ViewState and RenderState already at the client side, when objects are organized in a hierarchical way: the classic example are grouped draw shapes, whose parent group object imposes a common clipping and a common transformation on its siblings. The group object would therefore merge the ViewState and the RenderState it is called with into a new ViewState, and call its siblings with a RenderState containing only the local offset (and no extra clipping).
    
    Further on, this stateless nature provides easy ways for caching. Every non-trivial operation on XCanvas can return a cache object, which, when called to redraw, renders the primitive usually much more quickly than the original method. Note that such caching is a lot more complicated, should the actual rendering a method yields depend on internal state (which is the case e.g. for the com.sun.star.awt.XGraphics interface). Please note, though, that deciding whether to return an XCachedPrimitive is completely up to the implementation - don't rely on the methods returning something (this is because there might be cases when returning such a cache object will actually be a pessimization, since it involves memory allocation and comparisons).
    
    Things that need more than a small, fixed amount of data are encapsulated in own interfaces, e.g. polygons and bitmaps. You can, in principle, roll your own implementations of these interfaces, wrap it around your internal representation of polygons and bitmaps, and render them. It might just not be overly fast, because the XCanvas would need to convert for each render call. It is therefore recommended to create such objects via the XGraphicDevice factory (to be retrieved from every canvas object via the getDevice() call) - they will then internally optimize to the underlying graphics subsystem.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XCanvas <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XCanvas'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XCanvas'

    @abstractmethod
    def clear(self) -> None:
        """
        Clear the whole canvas area.
        
        This method clears the whole canvas area to the device default color (e.g. white for a printer, transparent for an XCustomSprite).
        """
        ...
    @abstractmethod
    def createFont(self, aFontRequest: FontRequest_e4890d46, aExtraFontProperties: typing.Tuple[PropertyValue_c9610c73, ...], aFontMatrix: Matrix2D_b26c0b5f) -> XCanvasFont_e3380d11:
        """
        Create a suitable font for the specified font description.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawBezier(self, aBezierSegment: RealBezierSegment2D_4a970fa2, aEndPoint: RealPoint2D_d6e70c78, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> None:
        """
        Draw a cubic Bezier curve in device resolution width (i.e.
        
        one device pixel wide).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawBitmap(self, xBitmap: XBitmap_b1b70b7b, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> XCachedPrimitive_29890f0f:
        """
        Render the given bitmap.
        
        This method renders the bitmap, at a position and shape as specified by the combined view and render transformations. For fast render speed, the bitmap should be created by the corresponding XGraphicDevice's XGraphicDevice.createCompatibleBitmap() method.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def drawBitmapModulated(self, xBitmap: XBitmap_b1b70b7b, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> XCachedPrimitive_29890f0f:
        """
        Render the given bitmap, with a global color modulation.
        
        This method renders the bitmap, at a position and shape as specified by the combined view and render transformations. For fast render speed, the bitmap should be created by the corresponding XGraphicDevice's XGraphicDevice.createCompatibleBitmap() method. The bitmap's color channel values are multiplied with the device color values as specified in the render state.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def drawLine(self, aStartPoint: RealPoint2D_d6e70c78, aEndPoint: RealPoint2D_d6e70c78, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> None:
        """
        Draw a line in device resolution width (i.e.
        
        one device pixel wide).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawPoint(self, aPoint: RealPoint2D_d6e70c78, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> None:
        """
        Draw a point in device resolution on the device.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> XCachedPrimitive_29890f0f:
        """
        Draw a poly-polygon in device resolution line width (i.e.
        
        the lines are one device pixel wide).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawText(self, aText: StringContext_d50e22, xFont: XCanvasFont_e3380d11, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, nTextDirection: int) -> XCachedPrimitive_29890f0f:
        """
        Draw the text given by the substring of the specified string with the given font.
        
        The local origin of this output operation is either the left end of the text baseline, for textDirection equal LEFT_TO_RIGHT, or the right end of the baseline, for textDirection equal to RIGHT_TO_LEFT, respectively.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def drawTextLayout(self, xLayoutetText: XTextLayout_e44a0d41, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> XCachedPrimitive_29890f0f:
        """
        Draw the formatted text given by the text layout.
        
        The glyphs as represented by the text layout are always output with the reference position being the leftmost edge of the layout object's baseline. If the layout contains more than one baseline, the baseline of the first strong character in logical order is used here (strong in this context means that the character can be unambiguously assigned to a Unicode script).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def fillPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> XCachedPrimitive_29890f0f:
        """
        Fill the given poly-polygon.
        
        This method fills the given poly-polygon according to the RenderState's color and the poly-polygon's fill rule.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def fillTextureMappedPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, xTextures: typing.Tuple[Texture_b2e70bb7, ...], xMapping: XMapping2D_ca1e0c0e) -> XCachedPrimitive_29890f0f:
        """
        Fill the given poly-polygon with a mapped texture.
        
        This method fills the given poly-polygon according to the RenderState's color, the given textures and poly-polygon's fill rule. The texture is mapped to the poly-polygon's interior via the given texture mapping.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def fillTexturedPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, xTextures: typing.Tuple[Texture_b2e70bb7, ...]) -> XCachedPrimitive_29890f0f:
        """
        Fill the given poly-polygon with a texture.
        
        This method fills the given poly-polygon according to the RenderState's color, the given textures and poly-polygon's fill rule.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def getDevice(self) -> XGraphicDevice_ca80e2c:
        """
        Request the associated graphic device for this canvas.
        
        A graphic device provides methods specific to the underlying output device capabilities, which are common for all canvases rendering to such a device. This includes device resolution, color space, or bitmap formats.
        """
        ...
    @abstractmethod
    def queryAvailableFonts(self, aFilter: FontInfo_bded0be9, aFontProperties: typing.Tuple[PropertyValue_c9610c73, ...]) -> typing.Tuple[FontInfo_bded0be9, ...]:
        """
        Query font information, specific to this canvas.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def queryStrokeShapes(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, aStrokeAttributes: StrokeAttributes_2dd10f65) -> XPolyPolygon2D_e1b0e20:
        """
        Query the polygonal representation of the stroke outlines, as it would be generated by the strokePolyPolygon methods.
        
        This method can be used to e.g. set a clipping which covers the same area as a stroke.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def strokePolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, aStrokeAttributes: StrokeAttributes_2dd10f65) -> XCachedPrimitive_29890f0f:
        """
        Stroke each polygon of the provided poly-polygon with the specified stroke attributes.
        
        This method considers the stroking of all polygons as an atomic operation in relation to the RenderState's CompositeOperationy operation. That means, overlapping strokes from distinct polygons will look exactly as overlapping segments of the same polygon, even with transparency.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def strokeTextureMappedPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, aTextures: typing.Tuple[Texture_b2e70bb7, ...], xMapping: XMapping2D_ca1e0c0e, aStrokeAttributes: StrokeAttributes_2dd10f65) -> XCachedPrimitive_29890f0f:
        """
        Stroke each polygon of the provided poly-polygon with the specified stroke attributes, fill the stroked outline with the specified texture graphics, map the texture to the outline via the specified texture mapping.
        
        This method considers the stroking of all polygons as an atomic operation in relation to the RenderState's CompositeOp operation. That means, overlapping strokes from distinct polygons will look exactly as overlapping segments of the same polygon, even with transparency.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...
    @abstractmethod
    def strokeTexturedPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27, aTextures: typing.Tuple[Texture_b2e70bb7, ...], aStrokeAttributes: StrokeAttributes_2dd10f65) -> XCachedPrimitive_29890f0f:
        """
        Stroke each polygon of the provided poly-polygon with the specified stroke attributes, fill the stroked outline with the specified texture graphics.
        
        This method considers the stroking of all polygons as an atomic operation in relation to the RenderState's CompositeOp operation. That means, overlapping strokes from distinct polygons will look exactly as overlapping segments of the same polygon, even with transparency.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            VolatileContentDestroyedException: ``VolatileContentDestroyedException``
        """
        ...

__all__ = ['XCanvas']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_closeable import XCloseable as XCloseable_98290a86
from .x_column_locate import XColumnLocate as XColumnLocate_ba5e0bc2
from .x_result_set import XResultSet as XResultSet_98e30aa7
from .x_result_set_meta_data_supplier import XResultSetMetaDataSupplier as XResultSetMetaDataSupplier_777010fc
from .x_result_set_update import XResultSetUpdate as XResultSetUpdate_e0fb0d0a
from .x_row import XRow as XRow_5f360834
from .x_row_update import XRowUpdate as XRowUpdate_989c0a97
from .x_warnings_supplier import XWarningsSupplier as XWarningsSupplier_ef210d99

class ResultSet(XPropertySet_bc180bfa, XComponent_98dc0ab5, XCloseable_98290a86, XColumnLocate_ba5e0bc2, XResultSet_98e30aa7, XResultSetMetaDataSupplier_777010fc, XResultSetUpdate_e0fb0d0a, XRow_5f360834, XRowUpdate_989c0a97, XWarningsSupplier_ef210d99):
    """
    Service Class

    provides access to a table of data.
    
    A ResultSet object is usually generated by executing a Statement.
    
    A ResultSet maintains a cursor pointing to its current row of data. Initially the cursor is positioned before the first row. The \"next\" method moves the cursor to the next row.
    
    The getXXX methods retrieve column values for the current row. You can retrieve values using either the index number of the column. Columns are numbered from 1.
    
    For maximum portability, ResultSet columns within each row should be read in left-to-right order and each column should be read only once.
    
    For the getXXX methods, the SDBC driver attempts to convert the underlying data to the specified type and returns a suitable value.
    
    Column names used as input to the findColumn method are case insensitive. When several columns have the same name, then the value of the first matching column will be returned. The column name option is designed to be used when column names are used in the SQL query. For columns that are NOT explicitly named in the query, it is best to use column numbers. If column names are used, there is no way for the programmer to guarantee that they actually refer to the intended columns.
    
    A ResultSet is automatically closed (disposed) by the Statement that generated it when that Statement is closed, re-executed, or used to retrieve the next result from a sequence of multiple results.
    
    The number, types, and properties of a ResultSet's columns are provided by the ResultSetMetaData object returned by the getMetaData method.

    See Also:
        `API ResultSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1ResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.ResultSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CursorName(self) -> str:
        """
        defines the SQL cursor name that will be used by subsequent Statement execute methods.
        
        This name can then be used in SQL positioned update/delete statements to identify the current row in the ResultSet generated by this statement. If the database doesn't support positioned update/delete, this property is a noop. To ensure that a cursor has the proper isolation level to support updates, the cursor's SELECT statement should be of the form \"select for update ...\". If the \"for update\" phrase is omitted, positioned updates may fail.
        
        Note:  By definition, positioned update/delete execution must be done by a different Statement than the one which generated the ResultSet being used for positioning. Also, cursor names must be unique within a connection.
        """
        ...

    @abstractproperty
    def FetchDirection(self) -> int:
        """
        retrieves the direction for fetching rows from database tables that is the default for result sets generated from this com.sun.star.sdbcx.Statement object.
        
        If this Statement object has not set a fetch direction, the return value is implementation-specific.
        """
        ...

    @abstractproperty
    def FetchSize(self) -> int:
        """
        retrieves the number of result set rows that is the default fetch size for result sets generated from this com.sun.star.sdbcx.Statement object.
        
        If this com.sun.star.sdbcx.Statement object has not set a fetch size, the return value is implementation-specific.
        """
        ...

    @abstractproperty
    def ResultSetConcurrency(self) -> int:
        """
        retrieves the result set concurrency.
        """
        ...

    @abstractproperty
    def ResultSetType(self) -> int:
        """
        determines the result set type.
        """
        ...


__all__ = ['ResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration
from __future__ import annotations
from ..beans.x_property import XProperty as XProperty_99770ace
from ..beans.x_property_with_state import XPropertyWithState as XPropertyWithState_c960e6b
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_hierarchical_name import XHierarchicalName as XHierarchicalName_3a4b0f63
from ..container.x_named import XNamed as XNamed_a6520b08

class HierarchyElement(XProperty_99770ace, XPropertyWithState_c960e6b, XChild_a6390b07, XHierarchicalName_3a4b0f63, XNamed_a6520b08):
    """
    Service Class

    provides information about an element within a hierarchy.
    
    The local name and the full hierarchical name can be retrieved. Attributes detailing the role of the element can be queried. The state of the element (regarding defaults) can be accessed.
    
    Implementations of this service usually also implement service HierarchyAccess, which concerns the complementary role of providing access to subelements of the hierarchy.

    See Also:
        `API HierarchyElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1HierarchyElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration'
    __ooo_full_ns__: str = 'com.sun.star.configuration.HierarchyElement'
    __ooo_type_name__: str = 'service'


__all__ = ['HierarchyElement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .interactive_io_exception import InteractiveIOException as InteractiveIOException_27a60f07
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..task.interaction_classification import InteractionClassification as InteractionClassification_6c4d10e7
from .io_error_code import IOErrorCode as IOErrorCode_96ab0a5f

class InteractiveAugmentedIOException(InteractiveIOException_27a60f07):
    """
    Exception Class

    An input/output error with arguments.

    See Also:
        `API InteractiveAugmentedIOException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1ucb_1_1InteractiveAugmentedIOException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.InteractiveAugmentedIOException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.ucb.InteractiveAugmentedIOException'
    __pyunostruct__: str = 'com.sun.star.ucb.InteractiveAugmentedIOException'

    typeName: str = 'com.sun.star.ucb.InteractiveAugmentedIOException'
    """Literal Constant ``com.sun.star.ucb.InteractiveAugmentedIOException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, Classification: typing.Optional[InteractionClassification_6c4d10e7] = InteractionClassification_6c4d10e7.ERROR, Code: typing.Optional[IOErrorCode_96ab0a5f] = IOErrorCode_96ab0a5f.ABORT, Arguments: typing.Optional[typing.Tuple[object, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            Classification (InteractionClassification, optional): Classification value.
            Code (IOErrorCode, optional): Code value.
            Arguments (typing.Tuple[object, ...], optional): Arguments value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "Classification": Classification,
            "Code": Code,
            "Arguments": Arguments,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._arguments = kwargs["Arguments"]
        inst_keys = ('Arguments',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def Arguments(self) -> typing.Tuple[object, ...]:
        """
        Additional arguments.
        
        See com.sun.star.task.InteractionHandler for a description of well-known arguments.
        """
        return self._arguments
    
    @Arguments.setter
    def Arguments(self, value: typing.Tuple[object, ...]) -> None:
        self._arguments = value


__all__ = ['InteractiveAugmentedIOException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class FloatingPointBitmapFormat(object):
    """
    Const Class

    This structure describes format of a floating point bitmap.
    
    **since**
    
        OOo 2.0

    See Also:
        `API FloatingPointBitmapFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1FloatingPointBitmapFormat.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.FloatingPointBitmapFormat'
    __ooo_type_name__: str = 'const'

    HALFFLOAT = 0
    """
    Half-float format.
    
    The color components are stored in the half-float format, i.e. in a 16 bit value, with 5 bit exponent, 10 bit mantissa and a sign bit. See also OpenEXR for a format employing half-floats.
    """
    FLOAT = 1
    """
    IEEE float format.
    
    The color components are stored in the IEEE single-precision floating point format, i.e. in a 32 bit value, with 8 bit exponent, 23 bit mantissa and a sign bit.
    """
    DOUBLE = 2
    """
    IEEE double format.
    
    The color components are stored in the IEEE double-precision floating point format, i.e. in a 64 bit value, with 16 bit exponent, 47 bit mantissa and a sign bit.
    """

__all__ = ['FloatingPointBitmapFormat']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_dialog import XDialog as XDialog_709d08fc

class XDialogEventHandler(XInterface_8f010a43):
    """
    Handles events fired by dialogs represented by a com.sun.star.awt.XDialog interface.

    See Also:
        `API XDialogEventHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDialogEventHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XDialogEventHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XDialogEventHandler'

    @abstractmethod
    def callHandlerMethod(self, xDialog: XDialog_709d08fc, EventObject: object, MethodName: str) -> bool:
        """
        Handles an event generated by a dialog.
        
        The implementation must be aware that the EventObject argument contains types which it is not prepared to handle. Similarly this applies for the MethodName argument. In this case the method should simply return false.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getSupportedMethodNames(self) -> typing.Tuple[str, ...]:
        """
        returns a sequence of supported method names
        """
        ...

__all__ = ['XDialogEventHandler']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.system.windows
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class JumpListItem(object):
    """
    Struct Class

    Specifies an item for com.sun.star.system.windows.XJumpList .
    
    **since**
    
        LibreOffice 7.4

    See Also:
        `API JumpListItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpListItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.system.windows'
    __ooo_full_ns__: str = 'com.sun.star.system.windows.JumpListItem'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.system.windows.JumpListItem'
    """Literal Constant ``com.sun.star.system.windows.JumpListItem``"""

    def __init__(self, name: typing.Optional[str] = '', description: typing.Optional[str] = '', arguments: typing.Optional[str] = '', iconPath: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            name (str, optional): name value.
            description (str, optional): description value.
            arguments (str, optional): arguments value.
            iconPath (str, optional): iconPath value.
        """
        super().__init__()

        if isinstance(name, JumpListItem):
            oth: JumpListItem = name
            self.name = oth.name
            self.description = oth.description
            self.arguments = oth.arguments
            self.iconPath = oth.iconPath
            return

        kargs = {
            "name": name,
            "description": description,
            "arguments": arguments,
            "iconPath": iconPath,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["name"]
        self._description = kwargs["description"]
        self._arguments = kwargs["arguments"]
        self._icon_path = kwargs["iconPath"]


    @property
    def name(self) -> str:
        """
        Item name.
        
        Appears in the JumpList. Has to be unique per category. Must not include embedded NULs ('\\0').
        """
        return self._name

    @name.setter
    def name(self, value: str) -> None:
        self._name = value

    @property
    def description(self) -> str:
        """
        Item description, appears as tooltip.
        
        Must not include embedded NULs ('\\0').
        """
        return self._description

    @description.setter
    def description(self, value: str) -> None:
        self._description = value

    @property
    def arguments(self) -> str:
        """
        Arguments to be passed to LibreOffice.
        
        This can be a file to be loaded, or any command line parameter supported by LibreOffice, and any combination of the two. Add multiple arguments separated by space. Must not include embedded NULs ('\\0').
        """
        return self._arguments

    @arguments.setter
    def arguments(self, value: str) -> None:
        self._arguments = value

    @property
    def iconPath(self) -> str:
        """
        Icon to be displayed along the name.
        
        Must be a local path name like C:\\\\path\\\\to\\\\icon.ico. Icon must be in ICO format.
        """
        return self._icon_path

    @iconPath.setter
    def iconPath(self, value: str) -> None:
        self._icon_path = value


__all__ = ['JumpListItem']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rdf
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FileFormat(metaclass=UnoConstMeta, type_name="com.sun.star.rdf.FileFormat", name_space="com.sun.star.rdf"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.rdf.FileFormat``"""
        pass

    class FileFormatEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.rdf.FileFormat", name_space="com.sun.star.rdf"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.rdf.FileFormat`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.rdf import FileFormat as FileFormat
    else:
        # keep document generators happy
        from ...lo.rdf.file_format import FileFormat as FileFormat

    class FileFormatEnum(IntEnum):
        """
        Enum of Const Class FileFormat

        Constants to specify RDF file formats.
        
        These constants are mainly for use with XRepository.importGraph() and XRepository.exportGraph().
        
        Note that these are integers because UNO IDL does not permit string constants.
        
        **since**
        
            OOo 3.0
        """
        RDF_XML = FileFormat.RDF_XML
        """
        RDF/XML
        """
        N3 = FileFormat.N3
        """
        N3 (Notation-3)
        """
        NTRIPLES = FileFormat.NTRIPLES
        """
        N-Triples
        """
        TRIG = FileFormat.TRIG
        """
        TriG
        """
        TRIX = FileFormat.TRIX
        """
        TriX
        """
        TURTLE = FileFormat.TURTLE
        """
        Turtle
        """

__all__ = ['FileFormat', 'FileFormatEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Implementation(object):
    """
    Struct Class

    Implementation name details returned in a sequence by XLocaleData.getCollatorImplementations().

    See Also:
        `API Implementation <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Implementation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.Implementation'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.Implementation'
    """Literal Constant ``com.sun.star.i18n.Implementation``"""

    def __init__(self, unoID: typing.Optional[str] = '', isDefault: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            unoID (str, optional): unoID value.
            isDefault (bool, optional): isDefault value.
        """
        super().__init__()

        if isinstance(unoID, Implementation):
            oth: Implementation = unoID
            self.unoID = oth.unoID
            self.isDefault = oth.isDefault
            return

        kargs = {
            "unoID": unoID,
            "isDefault": isDefault,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._uno_id = kwargs["unoID"]
        self._is_default = kwargs["isDefault"]


    @property
    def unoID(self) -> str:
        """
        The implementation name.
        """
        return self._uno_id

    @unoID.setter
    def unoID(self, value: str) -> None:
        self._uno_id = value

    @property
    def isDefault(self) -> bool:
        """
        If this is the default implementation.
        """
        return self._is_default

    @isDefault.setter
    def isDefault(self, value: bool) -> None:
        self._is_default = value


__all__ = ['Implementation']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
from ..lang.locale import Locale as Locale_70d308fa
from .single_proofreading_error import SingleProofreadingError as SingleProofreadingError_c54812c1
from .x_proofreader import XProofreader as XProofreader_dab0e46
from ..text.x_flat_paragraph import XFlatParagraph as XFlatParagraph_c8310c42


class ProofreadingResult(object):
    """
    Struct Class

    holds the results from proofreading a sentence.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API ProofreadingResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.ProofreadingResult'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.linguistic2.ProofreadingResult'
    """Literal Constant ``com.sun.star.linguistic2.ProofreadingResult``"""

    def __init__(self, aErrors: typing.Optional[typing.Tuple[SingleProofreadingError_c54812c1, ...]] = (), aProperties: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = (), aDocumentIdentifier: typing.Optional[str] = '', xFlatParagraph: typing.Optional[XFlatParagraph_c8310c42] = None, aText: typing.Optional[str] = '', aLocale: typing.Optional[Locale_70d308fa] = UNO_NONE, nStartOfSentencePosition: typing.Optional[int] = 0, nBehindEndOfSentencePosition: typing.Optional[int] = 0, nStartOfNextSentencePosition: typing.Optional[int] = 0, xProofreader: typing.Optional[XProofreader_dab0e46] = None) -> None:
        """
        Constructor

        Arguments:
            aErrors (typing.Tuple[SingleProofreadingError, ...], optional): aErrors value.
            aProperties (typing.Tuple[PropertyValue, ...], optional): aProperties value.
            aDocumentIdentifier (str, optional): aDocumentIdentifier value.
            xFlatParagraph (XFlatParagraph, optional): xFlatParagraph value.
            aText (str, optional): aText value.
            aLocale (Locale, optional): aLocale value.
            nStartOfSentencePosition (int, optional): nStartOfSentencePosition value.
            nBehindEndOfSentencePosition (int, optional): nBehindEndOfSentencePosition value.
            nStartOfNextSentencePosition (int, optional): nStartOfNextSentencePosition value.
            xProofreader (XProofreader, optional): xProofreader value.
        """
        super().__init__()

        if isinstance(aErrors, ProofreadingResult):
            oth: ProofreadingResult = aErrors
            self.aErrors = oth.aErrors
            self.aProperties = oth.aProperties
            self.aDocumentIdentifier = oth.aDocumentIdentifier
            self.xFlatParagraph = oth.xFlatParagraph
            self.aText = oth.aText
            self.aLocale = oth.aLocale
            self.nStartOfSentencePosition = oth.nStartOfSentencePosition
            self.nBehindEndOfSentencePosition = oth.nBehindEndOfSentencePosition
            self.nStartOfNextSentencePosition = oth.nStartOfNextSentencePosition
            self.xProofreader = oth.xProofreader
            return

        kargs = {
            "aErrors": aErrors,
            "aProperties": aProperties,
            "aDocumentIdentifier": aDocumentIdentifier,
            "xFlatParagraph": xFlatParagraph,
            "aText": aText,
            "aLocale": aLocale,
            "nStartOfSentencePosition": nStartOfSentencePosition,
            "nBehindEndOfSentencePosition": nBehindEndOfSentencePosition,
            "nStartOfNextSentencePosition": nStartOfNextSentencePosition,
            "xProofreader": xProofreader,
        }
        if kargs["aLocale"] is UNO_NONE:
            kargs["aLocale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._a_errors = kwargs["aErrors"]
        self._a_properties = kwargs["aProperties"]
        self._a_document_identifier = kwargs["aDocumentIdentifier"]
        self._x_flat_paragraph = kwargs["xFlatParagraph"]
        self._a_text = kwargs["aText"]
        self._a_locale = kwargs["aLocale"]
        self._n_start_of_sentence_position = kwargs["nStartOfSentencePosition"]
        self._n_behind_end_of_sentence_position = kwargs["nBehindEndOfSentencePosition"]
        self._n_start_of_next_sentence_position = kwargs["nStartOfNextSentencePosition"]
        self._x_proofreader = kwargs["xProofreader"]


    @property
    def aErrors(self) -> typing.Tuple[SingleProofreadingError_c54812c1, ...]:
        return self._a_errors

    @aErrors.setter
    def aErrors(self, value: typing.Tuple[SingleProofreadingError_c54812c1, ...]) -> None:
        self._a_errors = value

    @property
    def aProperties(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        return self._a_properties

    @aProperties.setter
    def aProperties(self, value: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        self._a_properties = value

    @property
    def aDocumentIdentifier(self) -> str:
        return self._a_document_identifier

    @aDocumentIdentifier.setter
    def aDocumentIdentifier(self, value: str) -> None:
        self._a_document_identifier = value

    @property
    def xFlatParagraph(self) -> XFlatParagraph_c8310c42:
        return self._x_flat_paragraph

    @xFlatParagraph.setter
    def xFlatParagraph(self, value: XFlatParagraph_c8310c42) -> None:
        self._x_flat_paragraph = value

    @property
    def aText(self) -> str:
        return self._a_text

    @aText.setter
    def aText(self, value: str) -> None:
        self._a_text = value

    @property
    def aLocale(self) -> Locale_70d308fa:
        return self._a_locale

    @aLocale.setter
    def aLocale(self, value: Locale_70d308fa) -> None:
        self._a_locale = value

    @property
    def nStartOfSentencePosition(self) -> int:
        return self._n_start_of_sentence_position

    @nStartOfSentencePosition.setter
    def nStartOfSentencePosition(self, value: int) -> None:
        self._n_start_of_sentence_position = value

    @property
    def nBehindEndOfSentencePosition(self) -> int:
        return self._n_behind_end_of_sentence_position

    @nBehindEndOfSentencePosition.setter
    def nBehindEndOfSentencePosition(self, value: int) -> None:
        self._n_behind_end_of_sentence_position = value

    @property
    def nStartOfNextSentencePosition(self) -> int:
        return self._n_start_of_next_sentence_position

    @nStartOfNextSentencePosition.setter
    def nStartOfNextSentencePosition(self, value: int) -> None:
        self._n_start_of_next_sentence_position = value

    @property
    def xProofreader(self) -> XProofreader_dab0e46:
        return self._x_proofreader

    @xProofreader.setter
    def xProofreader(self, value: XProofreader_dab0e46) -> None:
        self._x_proofreader = value


__all__ = ['ProofreadingResult']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..lang.locale import Locale as Locale_70d308fa
from .font_info import FontInfo as FontInfo_bded0be9


class FontRequest(object):
    """
    Struct Class

    This structure contains all information necessary to describe a font to be queried from XCanvas.
    
    Note: Outline fonts are to be requested as a special family, set FontInfo.FamilyName appropriately. Emboss/relief must be emulated by upper layers.
    
    Leave the FontInfo.FamilyName and FontInfo.StyleName empty, if font selection should only happen via the PANOSE description.
    
    **since**
    
        OOo 2.0

    See Also:
        `API FontRequest <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1FontRequest.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.FontRequest'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.rendering.FontRequest'
    """Literal Constant ``com.sun.star.rendering.FontRequest``"""

    def __init__(self, FontDescription: typing.Optional[FontInfo_bded0be9] = UNO_NONE, CellSize: typing.Optional[float] = 0.0, ReferenceAdvancement: typing.Optional[float] = 0.0, Locale: typing.Optional[Locale_70d308fa] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            FontDescription (FontInfo, optional): FontDescription value.
            CellSize (float, optional): CellSize value.
            ReferenceAdvancement (float, optional): ReferenceAdvancement value.
            Locale (Locale, optional): Locale value.
        """
        super().__init__()

        if isinstance(FontDescription, FontRequest):
            oth: FontRequest = FontDescription
            self.FontDescription = oth.FontDescription
            self.CellSize = oth.CellSize
            self.ReferenceAdvancement = oth.ReferenceAdvancement
            self.Locale = oth.Locale
            return

        kargs = {
            "FontDescription": FontDescription,
            "CellSize": CellSize,
            "ReferenceAdvancement": ReferenceAdvancement,
            "Locale": Locale,
        }
        if kargs["FontDescription"] is UNO_NONE:
            kargs["FontDescription"] = None
        if kargs["Locale"] is UNO_NONE:
            kargs["Locale"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._font_description = kwargs["FontDescription"]
        self._cell_size = kwargs["CellSize"]
        self._reference_advancement = kwargs["ReferenceAdvancement"]
        self._locale = kwargs["Locale"]


    @property
    def FontDescription(self) -> FontInfo_bded0be9:
        """
        The description of the font.
        
        This member contains the description of the font as returned by the font listing methods.
        """
        return self._font_description

    @FontDescription.setter
    def FontDescription(self, value: FontInfo_bded0be9) -> None:
        self._font_description = value

    @property
    def CellSize(self) -> float:
        """
        The size of the font in device coordinate space.
        
        This value corresponds to the font height in Western scripts, but is independent of the writing direction (see FontRequest.IsVertical below). That means, the value specified here is always measured orthogonal to the text advancement (height for horizontal writing, and width for vertical writing).
        
        When this value is negative, its absolute value is taken as the character size of the font. If this value is positive, it's taken as the cell size of the font.
        
        This member and the referenceAdvancement member are mutually exclusive, one of them has to be set to 0 (which means don't care).
        
        For distorted fonts, the render transformation must be used. That is, the size specified here corresponds to device pixel only if the combined render transformation during text output equals the identity transform. This also applies to all query methods, for both XCanvasFont and XTextLayout.
        """
        return self._cell_size

    @CellSize.setter
    def CellSize(self, value: float) -> None:
        self._cell_size = value

    @property
    def ReferenceAdvancement(self) -> float:
        """
        This value specifies the size of the font in the writing direction (i.e.
        
        width for horizontal writing, and height for vertical writing).
        
        It is equivalent to the referenceCharSize of the FontMetrics structure.
        
        This member and the cellSize member are mutually exclusive, one of them has to be set to 0 (which means don't care). For distorted fonts, the font matrix must be used.
        """
        return self._reference_advancement

    @ReferenceAdvancement.setter
    def ReferenceAdvancement(self, value: float) -> None:
        self._reference_advancement = value

    @property
    def Locale(self) -> Locale_70d308fa:
        """
        The locale this font should be able to render.
        
        This member supplements the FontInfo.UnicodeRange0 entry with a specific locale; this is e.g. important when selecting between traditional and simplified Chinese is necessary (since the letters have the same Unicode ranges and character values).
        """
        return self._locale

    @Locale.setter
    def Locale(self, value: Locale_70d308fa) -> None:
        self._locale = value


__all__ = ['FontRequest']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
import typing
from abc import abstractproperty
from ..form.binding.value_binding import ValueBinding as ValueBinding_18de0e7d
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
if typing.TYPE_CHECKING:
    from .cell_address import CellAddress as CellAddress_ae5f0b56

class CellValueBinding(ValueBinding_18de0e7d, XInitialization_d46c0cca):
    """
    Service Class

    defines the binding to a single cell in a table document
    
    Read/Write access to the cell represented by this component is supported, as well as active broadcasting of value changes.
    
    The binding supports exchanging double values, string values.
    
    The component cannot be instantiated at a global service factory, instead it's usually provided by a document instance.

    See Also:
        `API CellValueBinding <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1table_1_1CellValueBinding.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellValueBinding'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BoundCell(self) -> CellAddress_ae5f0b56:
        """
        specifies the cell within a document whose value is reflected by the binding.
        """
        ...


__all__ = ['CellValueBinding']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class VBAEventId(metaclass=UnoConstMeta, type_name="com.sun.star.script.vba.VBAEventId", name_space="com.sun.star.script.vba"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.script.vba.VBAEventId``"""
        pass

    class VBAEventIdEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.script.vba.VBAEventId", name_space="com.sun.star.script.vba"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.script.vba.VBAEventId`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.script.vba import VBAEventId as VBAEventId
    else:
        # keep document generators happy
        from ....lo.script.vba.vba_event_id import VBAEventId as VBAEventId

    class VBAEventIdEnum(IntEnum):
        """
        Enum of Const Class VBAEventId

        Constants used to identify VBA document events.
        
        If one of these events is fired, a specific VBA macro in a specific document code module will be executed.
        
        Each event expects some specific arguments to be passed to XVBAEventProcessor.processVbaEvent().
        """
        NO_EVENT = VBAEventId.NO_EVENT
        """
        An identifier not corresponding to any VBA document event.
        """
        AUTO_NEW = VBAEventId.AUTO_NEW
        """
        New document opened from template.
        
        No arguments.
        """
        AUTO_OPEN = VBAEventId.AUTO_OPEN
        """
        Document opened (loaded).
        
        No arguments.
        """
        AUTO_CLOSE = VBAEventId.AUTO_CLOSE
        """
        Document about to be closed.
        
        No arguments.
        """
        AUTO_EXEC = VBAEventId.AUTO_EXEC
        """
        Application start.
        
        No arguments.
        """
        AUTO_EXIT = VBAEventId.AUTO_EXIT
        """
        Application exit.
        
        No arguments.
        """
        DOCUMENT_NEW = VBAEventId.DOCUMENT_NEW
        """
        New text document opened from template.
        
        No arguments.
        """
        DOCUMENT_OPEN = VBAEventId.DOCUMENT_OPEN
        """
        Text document opened (loaded).
        
        No arguments.
        """
        DOCUMENT_CLOSE = VBAEventId.DOCUMENT_CLOSE
        """
        Document about to be closed.
        
        No arguments.
        """
        WORKBOOK_ACTIVATE = VBAEventId.WORKBOOK_ACTIVATE
        """
        Document activated.
        
        No arguments.
        """
        WORKBOOK_DEACTIVATE = VBAEventId.WORKBOOK_DEACTIVATE
        """
        Document deactivated.
        
        No arguments.
        """
        WORKBOOK_OPEN = VBAEventId.WORKBOOK_OPEN
        """
        Document opened (loaded).
        
        No arguments.
        """
        WORKBOOK_BEFORECLOSE = VBAEventId.WORKBOOK_BEFORECLOSE
        """
        Document about to be closed.
        
        Arguments: [out] boolean bCancel.
        """
        WORKBOOK_BEFOREPRINT = VBAEventId.WORKBOOK_BEFOREPRINT
        """
        Document about to be printed.
        
        Arguments: [out] boolean bCancel.
        """
        WORKBOOK_BEFORESAVE = VBAEventId.WORKBOOK_BEFORESAVE
        """
        Document about to be saved.
        
        Arguments: boolean bSaveAs, [out] boolean bCancel.
        """
        WORKBOOK_AFTERSAVE = VBAEventId.WORKBOOK_AFTERSAVE
        """
        Document has been saved.
        
        Arguments: boolean bSuccess.
        """
        WORKBOOK_NEWSHEET = VBAEventId.WORKBOOK_NEWSHEET
        """
        New sheet inserted.
        
        Arguments: short nSheet.
        """
        WORKBOOK_WINDOWACTIVATE = VBAEventId.WORKBOOK_WINDOWACTIVATE
        """
        Document window has been activated.
        
        Arguments: XController aController.
        """
        WORKBOOK_WINDOWDEACTIVATE = VBAEventId.WORKBOOK_WINDOWDEACTIVATE
        """
        Document window has been deactivated.
        
        Arguments: XController aController.
        """
        WORKBOOK_WINDOWRESIZE = VBAEventId.WORKBOOK_WINDOWRESIZE
        """
        Document window has been resized.
        
        Arguments: XController aController.
        """
        WORKSHEET_ACTIVATE = VBAEventId.WORKSHEET_ACTIVATE
        """
        Worksheet has been activated (made visible).
        
        Arguments: short nSheet.
        """
        WORKSHEET_DEACTIVATE = VBAEventId.WORKSHEET_DEACTIVATE
        """
        Worksheet has been activated (made visible).
        
        Arguments: short nSheet.
        """
        WORKSHEET_BEFOREDOUBLECLICK = VBAEventId.WORKSHEET_BEFOREDOUBLECLICK
        """
        Double click in the sheet.
        
        Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
        """
        WORKSHEET_BEFORERIGHTCLICK = VBAEventId.WORKSHEET_BEFORERIGHTCLICK
        """
        Right click in the sheet.
        
        Arguments: XRange/XSheetCellRangeContainer aRange, [out] boolean bCancel.
        """
        WORKSHEET_CALCULATE = VBAEventId.WORKSHEET_CALCULATE
        """
        Cells in sheet have been recalculated.
        
        Arguments: short nSheet.
        """
        WORKSHEET_CHANGE = VBAEventId.WORKSHEET_CHANGE
        """
        Cells in sheet have been changed.
        
        Arguments: XRange/XSheetCellRangeContainer aRange.
        """
        WORKSHEET_SELECTIONCHANGE = VBAEventId.WORKSHEET_SELECTIONCHANGE
        """
        Selection in sheet has been changed.
        
        Arguments: XRange/XSheetCellRangeContainer aRange.
        """
        WORKSHEET_FOLLOWHYPERLINK = VBAEventId.WORKSHEET_FOLLOWHYPERLINK
        """
        Hyperlink has been clicked.
        
        Arguments: XCell aCell.
        """
        USERDEFINED_START = VBAEventId.USERDEFINED_START
        """
        Implementations are allowed to use identifiers above this value for any internal purpose.
        """

__all__ = ['VBAEventId', 'VBAEventIdEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations


class AnimationCalcMode(object):
    """
    Const Class

    Specifies the interpolation mode for the animation.

    See Also:
        `API AnimationCalcMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1AnimationCalcMode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.AnimationCalcMode'
    __ooo_type_name__: str = 'const'

    DISCRETE = 0
    """
    This specifies that the animation function will jump from one value to the next without any interpolation.
    """
    LINEAR = 1
    """
    Simple linear interpolation between values is used to calculate the animation function.
    
    This is the default.
    """
    PACED = 2
    """
    Defines interpolation to produce an even pace of change across the animation.
    
    This is only supported for values that define a linear numeric range, and for which some notion of \"distance\" between points can be calculated (e.g. position, width, height, etc.).
    """
    SPLINE = 3
    """
    Interpolates from one value in the values list to the next according to a time function defined by a cubic Bezier spline.
    
    The points of the spline are defined in the XAnimate.KeyTimes attribute, and the control points for each interval are defined in the XAnimate.TimeFilter attribute.
    """

__all__ = ['AnimationCalcMode']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.registry
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_registry_key import XRegistryKey as XRegistryKey_e61a0d5b

class XSimpleRegistry(XInterface_8f010a43):
    """
    allows access to a registry (a persistent data source).
    
    The data is stored in a hierarchical key structure beginning with a root key. Each key can store a value and can have multiple subkeys.

    See Also:
        `API XSimpleRegistry <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.registry'
    __ooo_full_ns__: str = 'com.sun.star.registry.XSimpleRegistry'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.registry.XSimpleRegistry'

    @abstractmethod
    def close(self) -> None:
        """
        disconnects the registry from the data-source.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
        ...
    @abstractmethod
    def destroy(self) -> None:
        """
        destroys the registry and the data source.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
        ...
    @abstractmethod
    def getRootKey(self) -> XRegistryKey_e61a0d5b:
        """

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
        ...
    @abstractmethod
    def getURL(self) -> str:
        """
        returns the URL of the current data source of the registry.
        """
        ...
    @abstractmethod
    def isReadOnly(self) -> bool:
        """
        checks if the registry is readonly.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
        ...
    @abstractmethod
    def isValid(self) -> bool:
        """
        checks if the registry points to a valid data-source.
        """
        ...
    @abstractmethod
    def mergeKey(self, aKeyName: str, aUrl: str) -> None:
        """
        DEPRECATED: this method lacks a registry key (better than a URL).
        
        merges a registry under the specified key.
        
        If the key does not exist it will be created. Existing keys will be overridden from keys of registry specified by aUrl.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
            com.sun.star.registry.MergeConflictException: ``MergeConflictException``
        """
        ...
    @abstractmethod
    def open(self, rURL: str, bReadOnly: bool, bCreate: bool) -> None:
        """
        connects the registry to a persistent data source represented by a URL.
        
        If a local registry is already open, this function will close the currently open registry.

        Raises:
            com.sun.star.registry.InvalidRegistryException: ``InvalidRegistryException``
        """
        ...

__all__ = ['XSimpleRegistry']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.xml.sax.fast_parser import FastParser as FastParser
from ....lo.xml.sax.fast_token import FastToken as FastToken
from ....lo.xml.sax.fast_token_handler import FastTokenHandler as FastTokenHandler
from ....lo.xml.sax.input_source import InputSource as InputSource
from ....lo.xml.sax.parser import Parser as Parser
from ....lo.xml.sax.sax_exception import SAXException as SAXException
from ....lo.xml.sax.sax_invalid_character_exception import SAXInvalidCharacterException as SAXInvalidCharacterException
from ....lo.xml.sax.sax_parse_exception import SAXParseException as SAXParseException
from ....lo.xml.sax.writer import Writer as Writer
from ....lo.xml.sax.x_attribute_list import XAttributeList as XAttributeList
from ....lo.xml.sax.xdtd_handler import XDTDHandler as XDTDHandler
from ....lo.xml.sax.x_document_handler import XDocumentHandler as XDocumentHandler
from ....lo.xml.sax.x_entity_resolver import XEntityResolver as XEntityResolver
from ....lo.xml.sax.x_error_handler import XErrorHandler as XErrorHandler
from ....lo.xml.sax.x_extended_document_handler import XExtendedDocumentHandler as XExtendedDocumentHandler
from ....lo.xml.sax.x_fast_attribute_list import XFastAttributeList as XFastAttributeList
from ....lo.xml.sax.x_fast_context_handler import XFastContextHandler as XFastContextHandler
from ....lo.xml.sax.x_fast_document_handler import XFastDocumentHandler as XFastDocumentHandler
from ....lo.xml.sax.x_fast_namespace_handler import XFastNamespaceHandler as XFastNamespaceHandler
from ....lo.xml.sax.x_fast_parser import XFastParser as XFastParser
from ....lo.xml.sax.x_fast_sax_serializable import XFastSAXSerializable as XFastSAXSerializable
from ....lo.xml.sax.x_fast_token_handler import XFastTokenHandler as XFastTokenHandler
from ....lo.xml.sax.x_locator import XLocator as XLocator
from ....lo.xml.sax.x_parser import XParser as XParser
from ....lo.xml.sax.xsax_serializable import XSAXSerializable as XSAXSerializable
from ....lo.xml.sax.x_writer import XWriter as XWriter



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.logging.console_handler import ConsoleHandler as ConsoleHandler
with suppress(ImportError):
    from ...dyn.logging.csv_log_formatter import CsvLogFormatter as CsvLogFormatter
with suppress(ImportError):
    from ...dyn.logging.file_handler import FileHandler as FileHandler
with suppress(ImportError):
    from ...dyn.logging.log_level import LogLevel as LogLevel
with suppress(ImportError):
    from ...dyn.logging.log_level import LogLevelEnum as LogLevelEnum
with suppress(ImportError):
    from ...dyn.logging.log_record import LogRecord as LogRecord
with suppress(ImportError):
    from ...dyn.logging.logger_pool import LoggerPool as LoggerPool
with suppress(ImportError):
    from ...dyn.logging.plain_text_formatter import PlainTextFormatter as PlainTextFormatter
with suppress(ImportError):
    from ...dyn.logging.simple_text_formatter import SimpleTextFormatter as SimpleTextFormatter
with suppress(ImportError):
    from ...dyn.logging.x_console_handler import XConsoleHandler as XConsoleHandler
with suppress(ImportError):
    from ...dyn.logging.x_csv_log_formatter import XCsvLogFormatter as XCsvLogFormatter
with suppress(ImportError):
    from ...dyn.logging.x_log_formatter import XLogFormatter as XLogFormatter
with suppress(ImportError):
    from ...dyn.logging.x_log_handler import XLogHandler as XLogHandler
with suppress(ImportError):
    from ...dyn.logging.x_logger import XLogger as XLogger
with suppress(ImportError):
    from ...dyn.logging.x_logger_pool import XLoggerPool as XLoggerPool



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6

class XRubySelection(XInterface_8f010a43):
    """
    This interface enables the object to handle list of ruby lines (aka Furigana lines).

    See Also:
        `API XRubySelection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XRubySelection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XRubySelection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XRubySelection'

    @abstractmethod
    def getRubyList(self, Automatic: bool) -> typing.Tuple[PropertyValues_d6470ce6, ...]:
        """
        returns a sequence of ruby elements.
        
        Each element contains at least a string that contains the selected text and the ruby text. Additional parameters can be the ruby adjustment, the name of a character style.
        """
        ...
    @abstractmethod
    def setRubyList(self, RubyList: typing.Tuple[PropertyValues_d6470ce6, ...], Automatic: bool) -> None:
        """
        applies the RubyList to the current selection.
        
        The number of elements must be equal to the number of elements that are returned by getRubyList. Automatic must be set equally, too.
        """
        ...

__all__ = ['XRubySelection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...lang.locale import Locale as Locale_70d308fa
    from .input_source import InputSource as InputSource_c88c0c54
    from .xdtd_handler import XDTDHandler as XDTDHandler_c3df0bc5
    from .x_document_handler import XDocumentHandler as XDocumentHandler_9b90e28
    from .x_entity_resolver import XEntityResolver as XEntityResolver_fcf10dfa
    from .x_error_handler import XErrorHandler as XErrorHandler_e0860cf3

class XParser(XInterface_8f010a43):
    """
    specifies a SAX parser.
    
    This interface is an IDL version of the Java interface org.xml.sax.Parser with some minor adaptations.

    See Also:
        `API XParser <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XParser.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XParser'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XParser'

    @abstractmethod
    def parseStream(self, aInputSource: InputSource_c88c0c54) -> None:
        """
        parses an XML document from a stream.
        
        Set the desired handlers before calling this method.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def setDTDHandler(self, xHandler: XDTDHandler_c3df0bc5) -> None:
        """
        allows an application to register a DTD-Handler.
        """
        ...
    @abstractmethod
    def setDocumentHandler(self, xHandler: XDocumentHandler_9b90e28) -> None:
        """
        allows an application to register a document event handler.
        """
        ...
    @abstractmethod
    def setEntityResolver(self, xResolver: XEntityResolver_fcf10dfa) -> None:
        """
        allows an application to register a DTD-Handler.
        """
        ...
    @abstractmethod
    def setErrorHandler(self, xHandler: XErrorHandler_e0860cf3) -> None:
        """
        allows an application to register an error event handler.
        
        Note that the error handler can throw an exception when an error or warning occurs. Note that an exception is thrown by the parser when an unrecoverable (fatal) error occurs.
        """
        ...
    @abstractmethod
    def setLocale(self, locale: Locale_70d308fa) -> None:
        """
        sets a locale specified for localization of warnings and error messages.
        
        Set the language of the error messages. Useful when the parsing errors will be presented to the user.
        """
        ...

__all__ = ['XParser']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .xdom_implementation import XDOMImplementation as XDOMImplementation_22320ec5
    from .x_document import XDocument as XDocument_aebc0b5e
    from ..sax.x_entity_resolver import XEntityResolver as XEntityResolver_fcf10dfa
    from ..sax.x_error_handler import XErrorHandler as XErrorHandler_e0860cf3

class XDocumentBuilder(XInterface_8f010a43):
    """
    Builds a new dom tree.

    See Also:
        `API XDocumentBuilder <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocumentBuilder.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XDocumentBuilder'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XDocumentBuilder'

    @abstractmethod
    def getDOMImplementation(self) -> XDOMImplementation_22320ec5:
        """
        Obtain an instance of a DOMImplementation object.
        """
        ...
    @abstractmethod
    def isNamespaceAware(self) -> bool:
        """
        Indicates whether or not this parser is configured to understand namespaces.
        """
        ...
    @abstractmethod
    def isValidating(self) -> bool:
        """
        Indicates whether or not this parser is configured to validate XML documents.
        """
        ...
    @abstractmethod
    def newDocument(self) -> XDocument_aebc0b5e:
        """
        Obtain a new instance of a DOM Document object to build a DOM tree with.
        """
        ...
    @abstractmethod
    def parse(self, is_: XInputStream_98d40ab4) -> XDocument_aebc0b5e:
        """
        Parse the content of the given InputStream as an XML document and return a new DOM Document object.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def parseURI(self, uri: str) -> XDocument_aebc0b5e:
        """
        Parse the content of the given URI as an XML document and return a new DOM Document object.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def setEntityResolver(self, er: XEntityResolver_fcf10dfa) -> None:
        """
        Specify the EntityResolver to be used to resolve entities present in the XML document to be parsed.
        """
        ...
    @abstractmethod
    def setErrorHandler(self, eh: XErrorHandler_e0860cf3) -> None:
        """
        Specify the ErrorHandler to be used to report errors present in the XML document to be parsed.
        """
        ...

__all__ = ['XDocumentBuilder']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_security_environment import XSecurityEnvironment as XSecurityEnvironment_7ead116d
    from .xxml_encryption_template import XXMLEncryptionTemplate as XXMLEncryptionTemplate_9c6511d8
    from .xxml_security_context import XXMLSecurityContext as XXMLSecurityContext_681010ae

class XXMLEncryption(XInterface_8f010a43):
    """
    Interface of XML encryption.
    
    This interface represents a XML encryptor or decryptor.
    
    The encryptor or decryptor concrete a key by retrieve security context and encryption template.
    
    In some cases, the encryptor or decryptor can determine and locate the EncryptedKey from the encryption template by dereference the RetrievalMethod inside EncryptedData.
    
    In some cases, the EncryptedKey need to be clearly pointed out by the encryption template.

    See Also:
        `API XXMLEncryption <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLEncryption.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.XXMLEncryption'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.crypto.XXMLEncryption'

    @abstractmethod
    def decrypt(self, aTemplate: XXMLEncryptionTemplate_9c6511d8, aContext: XXMLSecurityContext_681010ae) -> XXMLEncryptionTemplate_9c6511d8:
        """
        Perform decryption in the environment of encryption template and context.

        Raises:
            : ````
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
        ...
    @abstractmethod
    def encrypt(self, aTemplate: XXMLEncryptionTemplate_9c6511d8, aEnvironment: XSecurityEnvironment_7ead116d) -> XXMLEncryptionTemplate_9c6511d8:
        """
        Perform encryption in the environment of encryption template and context.

        Raises:
            : ````
            com.sun.star.uno.SecurityException: ``SecurityException``
        """
        ...

__all__ = ['XXMLEncryption']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .localized_name import LocalizedName as LocalizedName_c89d0c39

class XCompatibilityNames(XInterface_8f010a43):
    """
    gives access to the sequence of compatibility names for an Addin function.

    See Also:
        `API XCompatibilityNames <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCompatibilityNames.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XCompatibilityNames'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XCompatibilityNames'

    @abstractmethod
    def getCompatibilityNames(self, aProgrammaticName: str) -> typing.Tuple[LocalizedName_c89d0c39, ...]:
        """
        returns the compatibility names of the specified function.
        
        Compatibility names are localized names of AddIn functions that are used to import files from other applications.
        
        If on import a localized function name is read, this list of compatibility names is used to find the internal name of the function. The current locale may differ from the locale used in the imported file, so the method XAddIn.getProgrammaticFuntionName() cannot be used here.
        
        The order inside the sequence of compatibility names is used to prioritize the names. Initially the first compatibility name of each function is compared to the imported name (each function may provide a sequence of compatibility names - the first entry of all sequences is used). If no entry is equal, the second entry of each sequence is used and so on.
        
        If a locale is not present in the sequence of compatibility names, the first entry of the sequence is used. So the method should return a sequence which contains first the entry representing the current locale.TRUE
        """
        ...

__all__ = ['XCompatibilityNames']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .all_event_object import AllEventObject as AllEventObject_e2c20d0f
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class ScriptEvent(AllEventObject_e2c20d0f):
    """
    Struct Class

    script event that gets delivered whenever a script event takes place.
    
    For that to happen, a \"ScriptEventDescriptor\" must be registered at and attached to an object by an XEventAttacherManager.

    See Also:
        `API ScriptEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1ScriptEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.ScriptEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.script.ScriptEvent'
    """Literal Constant ``com.sun.star.script.ScriptEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Arguments: typing.Optional[typing.Tuple[object, ...]] = (), Helper: typing.Optional[object] = None, ListenerType: typing.Optional[object] = None, MethodName: typing.Optional[str] = '', ScriptType: typing.Optional[str] = '', ScriptCode: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Arguments (typing.Tuple[object, ...], optional): Arguments value.
            Helper (object, optional): Helper value.
            ListenerType (object, optional): ListenerType value.
            MethodName (str, optional): MethodName value.
            ScriptType (str, optional): ScriptType value.
            ScriptCode (str, optional): ScriptCode value.
        """

        if isinstance(Source, ScriptEvent):
            oth: ScriptEvent = Source
            self.Source = oth.Source
            self.Arguments = oth.Arguments
            self.Helper = oth.Helper
            self.ListenerType = oth.ListenerType
            self.MethodName = oth.MethodName
            self.ScriptType = oth.ScriptType
            self.ScriptCode = oth.ScriptCode
            return

        kargs = {
            "Source": Source,
            "Arguments": Arguments,
            "Helper": Helper,
            "ListenerType": ListenerType,
            "MethodName": MethodName,
            "ScriptType": ScriptType,
            "ScriptCode": ScriptCode,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._script_type = kwargs["ScriptType"]
        self._script_code = kwargs["ScriptCode"]
        inst_keys = ('ScriptType', 'ScriptCode')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def ScriptType(self) -> str:
        """
        type of the script language as string; for example, \"Basic\" or \"StarScript\".
        """
        return self._script_type

    @ScriptType.setter
    def ScriptType(self, value: str) -> None:
        self._script_type = value

    @property
    def ScriptCode(self) -> str:
        """
        script code as string.
        
        The code has to correspond with the language defined by ScriptType.
        """
        return self._script_code

    @ScriptCode.setter
    def ScriptCode(self, value: str) -> None:
        self._script_code = value


__all__ = ['ScriptEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ImageStatus(metaclass=UnoConstMeta, type_name="com.sun.star.awt.ImageStatus", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.ImageStatus``"""
        pass

    class ImageStatusEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.ImageStatus", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.ImageStatus`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import ImageStatus as ImageStatus
    else:
        # keep document generators happy
        from ...lo.awt.image_status import ImageStatus as ImageStatus

    class ImageStatusEnum(IntEnum):
        """
        Enum of Const Class ImageStatus

        These values are used to specify to which degree an image is available.
        """
        IMAGESTATUS_ERROR = ImageStatus.IMAGESTATUS_ERROR
        """
        This conveys that an error was encountered while producing the image.
        """
        IMAGESTATUS_SINGLEFRAMEDONE = ImageStatus.IMAGESTATUS_SINGLEFRAMEDONE
        """
        This conveys that one frame of the image is complete but there are more frames to be delivered.
        """
        IMAGESTATUS_STATICIMAGEDONE = ImageStatus.IMAGESTATUS_STATICIMAGEDONE
        """
        This conveys that the image is complete and there are no more pixels or frames to be delivered.
        """
        IMAGESTATUS_ABORTED = ImageStatus.IMAGESTATUS_ABORTED
        """
        This conveys that the image creation process was deliberately aborted.
        """

__all__ = ['ImageStatus', 'ImageStatusEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Currency(object):
    """
    Struct Class

    Symbols, names, and attributes of a specific currency, returned in a sequence by XLocaleData.getAllCurrencies().

    See Also:
        `API Currency <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1Currency.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.Currency'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.Currency'
    """Literal Constant ``com.sun.star.i18n.Currency``"""

    def __init__(self, ID: typing.Optional[str] = '', Symbol: typing.Optional[str] = '', BankSymbol: typing.Optional[str] = '', Name: typing.Optional[str] = '', Default: typing.Optional[bool] = False, UsedInCompatibleFormatCodes: typing.Optional[bool] = False, DecimalPlaces: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            ID (str, optional): ID value.
            Symbol (str, optional): Symbol value.
            BankSymbol (str, optional): BankSymbol value.
            Name (str, optional): Name value.
            Default (bool, optional): Default value.
            UsedInCompatibleFormatCodes (bool, optional): UsedInCompatibleFormatCodes value.
            DecimalPlaces (int, optional): DecimalPlaces value.
        """
        super().__init__()

        if isinstance(ID, Currency):
            oth: Currency = ID
            self.ID = oth.ID
            self.Symbol = oth.Symbol
            self.BankSymbol = oth.BankSymbol
            self.Name = oth.Name
            self.Default = oth.Default
            self.UsedInCompatibleFormatCodes = oth.UsedInCompatibleFormatCodes
            self.DecimalPlaces = oth.DecimalPlaces
            return

        kargs = {
            "ID": ID,
            "Symbol": Symbol,
            "BankSymbol": BankSymbol,
            "Name": Name,
            "Default": Default,
            "UsedInCompatibleFormatCodes": UsedInCompatibleFormatCodes,
            "DecimalPlaces": DecimalPlaces,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._id = kwargs["ID"]
        self._symbol = kwargs["Symbol"]
        self._bank_symbol = kwargs["BankSymbol"]
        self._name = kwargs["Name"]
        self._default = kwargs["Default"]
        self._used_in_compatible_format_codes = kwargs["UsedInCompatibleFormatCodes"]
        self._decimal_places = kwargs["DecimalPlaces"]


    @property
    def ID(self) -> str:
        """
        ISO 4217 currency code identifier, for example, EUR or USD.
        """
        return self._id

    @ID.setter
    def ID(self, value: str) -> None:
        self._id = value

    @property
    def Symbol(self) -> str:
        """
        Currency symbol, for example, $.
        """
        return self._symbol

    @Symbol.setter
    def Symbol(self, value: str) -> None:
        self._symbol = value

    @property
    def BankSymbol(self) -> str:
        """
        Currency abbreviation used by banks and in money exchange, for example, EUR or USD.
        
        This usually should be identical to the ISO 4217 currency code also used in the ID, but doesn't necessarily have to be.
        """
        return self._bank_symbol

    @BankSymbol.setter
    def BankSymbol(self, value: str) -> None:
        self._bank_symbol = value

    @property
    def Name(self) -> str:
        """
        Name of the currency, for example, Euro or US Dollar.
        
        Should be the localized name.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def Default(self) -> bool:
        """
        If this currency is the default currency for a given locale.
        """
        return self._default

    @Default.setter
    def Default(self, value: bool) -> None:
        self._default = value

    @property
    def UsedInCompatibleFormatCodes(self) -> bool:
        """
        If this currency is the one used in compatible number format codes with FormatElement.formatIndex() values in the range 12..17.
        
        Those format codes are used to generate some old style currency format codes for compatibility with StarOffice5 and StarOffice4.
        """
        return self._used_in_compatible_format_codes

    @UsedInCompatibleFormatCodes.setter
    def UsedInCompatibleFormatCodes(self, value: bool) -> None:
        self._used_in_compatible_format_codes = value

    @property
    def DecimalPlaces(self) -> int:
        """
        The number of decimal places, for example, 2 for US Dollar or 0 for Italian Lira.
        """
        return self._decimal_places

    @DecimalPlaces.setter
    def DecimalPlaces(self, value: int) -> None:
        self._decimal_places = value


__all__ = ['Currency']
